@@ -73,6 +73,7 @@ class BaseDatabase(ABC):
         self.conn_id = conn_id
         self.sql: str | ClauseElement = ""
         self.load_options = load_options
+        self.table = table
 
     def __repr__(self):
         return f'{self.__class__.__name__}(conn_id="{self.conn_id})'
@@ -613,7 +614,7 @@ class BaseDatabase(ABC):
 
         source_dataframe.to_sql(
             self.get_table_qualified_name(target_table),
-            con=self.sqlalchemy_engine,
+            con=self.connection,
             if_exists=if_exists,
             chunksize=chunk_size,
             method="multi",
