@@ -21,9 +21,9 @@ from astro.databases import create_database
 from astro.files import File
 from astro.sql.operators.base_operator import AstroSQLBaseOperator
 from astro.sql.table import BaseTable, Table
+from astro.utils.compat.typing import Context
 from astro.utils.dataframe import convert_columns_names_capitalization
 from astro.utils.table import find_first_table
-from astro.utils.typing_compat import Context
 
 
 def _get_dataframe(
