@@ -5,12 +5,14 @@ from collections.abc import Iterable, Mapping
 from typing import Any, Callable
 
 try:
-    from airflow.decorators.base import TaskDecorator, task_decorator_factory
+    from airflow.decorators.base import TaskDecorator
 except ImportError:
-    from airflow.decorators.base import task_decorator_factory
     from airflow.decorators import _TaskDecorator as TaskDecorator
 
 import airflow
+import pandas as pd
+from airflow.decorators.base import task_decorator_factory
+from sqlalchemy.engine import ResultProxy
 
 if airflow.__version__ >= "2.3":
     from sqlalchemy.engine.row import LegacyRow as SQLAlcRow
@@ -18,6 +20,8 @@ else:
     from sqlalchemy.engine.result import RowProxy as SQLAlcRow
 
 from astro import settings
+from astro.constants import RunRawSQLResultFormat
+from astro.dataframes.pandas import PandasDataframe
 from astro.exceptions import IllegalLoadToDatabaseException
 from astro.sql.operators.base_decorator import BaseSQLDecoratedOperator
 from astro.utils.compat.typing import Context
@@ -32,9 +36,22 @@ class RawSQLOperator(BaseSQLDecoratedOperator):
     and on the SQL statement/function declared by the user.
     """
 
+    def __init__(
+        self,
+        results_format: RunRawSQLResultFormat | None = None,
+        fail_on_empty: bool = False,
+        **kwargs: Any,
+    ):
+        super().__init__(**kwargs)
+
+        # add the results_format and fail_on_empty to the kwargs
+        self.results_format = results_format
+        self.fail_on_empty = fail_on_empty
+
     def execute(self, context: Context) -> Any:
         super().execute(context)
 
+        self.handler = self.get_handler()
         result = self.database_impl.run_sql(sql=self.sql, parameters=self.parameters, handler=self.handler)
         if self.response_size == -1 and not settings.IS_CUSTOM_XCOM_BACKEND:
             logging.warning(
@@ -44,19 +61,21 @@ class RawSQLOperator(BaseSQLDecoratedOperator):
                 "backend."
             )
 
-        if self.handler and self.database_impl.sql_type == "delta":
-            return result
-        elif self.handler:
-            response = self.handler(result)
-            response = self.make_row_serializable(response)
+        if self.handler:
+            response = self.make_row_serializable(result)
             if 0 <= self.response_limit < len(response):
                 raise IllegalLoadToDatabaseException()  # pragma: no cover
             if self.response_size >= 0:
-                return response[: self.response_size]
+                resp = response[: self.response_size]
+                # We do the following is slicing pandas dataframe creates a pd.Dataframe object
+                # which isn't serializable
+                # TODO: We could add a __getitem__ to PandasDataframe object
+                return PandasDataframe.from_pandas_df(resp) if isinstance(resp, pd.DataFrame) else resp
             else:
                 return response
-        else:
-            return None
+
+        # if no results_format or handler is specified, we don't return results
+        return None
 
     @staticmethod
     def make_row_serializable(rows: Any) -> Any:
@@ -65,10 +84,63 @@ class RawSQLOperator(BaseSQLDecoratedOperator):
         """
         if not settings.NEED_CUSTOM_SERIALIZATION:
             return rows
+        if isinstance(rows, PandasDataframe):
+            return rows
         if isinstance(rows, Iterable):
             return [SdkLegacyRow.from_legacy_row(r) if isinstance(r, SQLAlcRow) else r for r in rows]
         return rows
 
+    @staticmethod
+    def results_as_list(results: ResultProxy) -> list:
+        """
+        Convert the result of a SQL query to a list
+        """
+        data = []
+        for result in results.fetchall():
+            data.append(result.values())
+        return data
+
+    @staticmethod
+    def results_as_pandas_dataframe(result: ResultProxy) -> pd.DataFrame:
+        """
+        Convert the result of a SQL query to a pandas dataframe
+        """
+        return PandasDataframe(result.fetchall(), columns=result.keys())
+
+    def get_results_format_handler(self, results_format: str):
+        return getattr(self, f"results_as_{results_format}")
+
+    def get_handler(self):
+        # if a user specifies a results_format, we will return the results in that format
+        # note that it takes precedence over the handler
+        if self.results_format:
+            self.handler = self.get_results_format_handler(results_format=self.results_format)
+            logging.info("Provided 'handler' will be overridden when 'results_format' is given.")
+        if self.handler:
+            self.handler = self.get_wrapped_handler(
+                fail_on_empty=self.fail_on_empty, conversion_func=self.handler
+            )
+        return self.handler
+
+    @staticmethod
+    def get_wrapped_handler(fail_on_empty: bool, conversion_func: Callable):
+        # if fail_on_empty is set to False, wrap in a try/except block
+        # this is because the conversion function will fail if the result is empty
+        # due to sqlalchemy failing when there are no results
+        if not fail_on_empty:
+
+            def handle_exceptions(result):
+                try:
+                    return conversion_func(result)
+                except Exception as e:  # skipcq: PYL-W0703
+                    logging.info("Exception %s handled since 'fail_on_empty' parameter was passed", str(e))
+                    return None
+
+            return handle_exceptions
+
+        # otherwise, just return the result
+        return conversion_func
+
 
 class SdkLegacyRow(SQLAlcRow):
     version: int = 1
@@ -92,6 +164,8 @@ def run_raw_sql(
     database: str | None = None,
     schema: str | None = None,
     handler: Callable | None = None,
+    results_format: RunRawSQLResultFormat | None = None,
+    fail_on_empty: bool = False,
     response_size: int = settings.RAW_SQL_MAX_RESPONSE_SIZE,
     **kwargs: Any,
 ) -> TaskDecorator:
@@ -130,6 +204,8 @@ def run_raw_sql(
         (required if there are no table arguments)
     :param handler: Handler function to process the result of the SQL query. For more information please consult
         https://docs.sqlalchemy.org/en/14/core/connections.html#sqlalchemy.engine.Result
+    :param results_format: Format of the results returned by the SQL query. Overrides the handler, if provided.
+    :param fail_on_empty: If True and a results_format is provided, raises an exception if the query returns no results.
     :param response_size: Used to trim the responses returned to avoid trashing the Airflow DB.
         The default value is -1, which means the response is not changed. Otherwise, if the response is a list,
         returns up to the desired amount of items. If the response is a string, trims it to the desired size.
@@ -145,6 +221,8 @@ def run_raw_sql(
             "database": database,
             "schema": schema,
             "handler": handler,
+            "results_format": results_format,
+            "fail_on_empty": fail_on_empty,
             "response_size": response_size,
         }
     )
